==> deepin-log-viewer_5.9.7+ds1.orig.tar.xz: deepin-log-viewer-5.9.7/translations/deepin-log-viewer_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Näytä tiedostohallinnassa</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Tyhjennä tapahtumaloki</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Päivitä</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Haluatko varmasti tyhjentää tapahtumalokin?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Vahvista</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Kaikki</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Tänään</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 päivää</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 viikko</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 kuukausi</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 kuukautta</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Vie</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Vie</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Kaikki</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Hätä</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Hälytys</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kriittinen</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Varoitus</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Ilmoitus</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Tiedot</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Vianetsintä</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Kirjaudu</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Käynnistys</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Sammuta</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Kriittinen</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Jäljitys</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Viedään...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Vienti onnistui</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Vienti epäonnistui</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Vie tiedosto</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Aikaväli:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Taso:</translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>Sovellusluettelo:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Tila:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Tapahtumat:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Käyttäjä:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Toiminta:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Käyttäjänimi:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Käynnistyskerrat</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Sammutettu</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Kirjautumiset</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Varoitus</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Vianetsintä</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Tiedot</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Hätä</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Hälytys</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kriittinen</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Ilmoitus</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Jäljitys</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Kriittinen</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Lokitiedosto on tyhjä</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Tapahtumaloki</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Tapahtumaloki on hyödyllinen työkalu järjestelmän tarkasteluun.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Ei hakutuloksia</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Etsi</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Taso</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Prosessi</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Päivämäärä ja aika</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Tiedot</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Käyttäjä</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Lähde</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Toiminta</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Tila</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Tapahtumat</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Käyttäjänimi</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Taso:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Prosessi:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Päivämäärä ja aika:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Info:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Tyhjä</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Käyttäjä:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Päivä ja aika</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Järjestelmä</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Kernel</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Boot</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>dpkg</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Kwin loki</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Sovellukset</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Kirjautumiset</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>dnf loki</translation>
    </message>
</context>
</TS>

==> deepin-log-viewer_6.5.8+ds1.orig.tar.xz: deepin-log-viewer-6.5.8/translations/deepin-log-viewer_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Näytä tiedostohallinnassa</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Tyhjennä tapahtumaloki</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Päivitä</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Haluatko varmasti tyhjentää tapahtumalokin?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Vahvista</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Kaikki</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Tänään</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 päivää</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 viikko</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 kuukausi</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 kuukautta</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Vie</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Kaikki</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Hätä</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Hälytys</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kriittinen</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Varoitus</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Ilmoitus</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Tiedot</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Vianetsintä</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Kirjaudu</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Käynnistys</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Sammuta</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Kriittinen</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Jäljitys</translation>
    </message>
    <message>
        <source>Identity authentication</source>
        <translation>Henkilöllisyyden todennus</translation>
    </message>
    <message>
        <source>Discretionary Access Control</source>
        <translation>Harkittu pääsynhallinta</translation>
    </message>
    <message>
        <source>Mandatory access control</source>
        <translation>Pakollinen pääsynhallinta</translation>
    </message>
    <message>
        <source>Remote</source>
        <translation>Etäyhteys</translation>
    </message>
    <message>
        <source>Document audit</source>
        <translation>Asiakirjan tarkastus</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Muu</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>zip(*.zip)</source>
        <translation>zip(*.zip)</translation>
    </message>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Viedään...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Vienti onnistui</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Vienti epäonnistui</translation>
    </message>
    <message>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation>Vientihakemisto ei ole käytettävissä. Valitse toinen hakemisto toimintoa varten.</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Vie tiedosto</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Aikaväli:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Taso:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Tila:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Tapahtumat:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Käyttäjä:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Toiminta:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Käyttäjänimi:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Käynnistyskerrat</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Sammutettu</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Kirjautumiset</translation>
    </message>
    <message>
        <source>Audit Type:</source>
        <translation>Tarkastustyyppi:</translation>
    </message>
    <message>
        <source>Application:</source>
        <translation>Sovellukset:</translation>
    </message>
    <message>
        <source>Submodule:</source>
        <translation>Alamoduuli:</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Varoitus</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Vianetsintä</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Tiedot</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Hätä</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Hälytys</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kriittinen</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Ilmoitus</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Jäljitys</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Kriittinen</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Lokitiedosto on tyhjä</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Tapahtumaloki</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Tapahtumaloki on hyödyllinen työkalu järjestelmän tarkasteluun.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Ei hakutuloksia</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Etsi</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Taso</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Prosessi</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Päivämäärä ja aika</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Tiedot</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Käyttäjä</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Lähde</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Toiminta</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Tila</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Tapahtumat</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Käyttäjänimi</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Taso:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Prosessi:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Päivämäärä ja aika:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Info:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Tyhjä</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Käyttäjä:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation>Tiedostonimi</translation>
    </message>
    <message>
        <source>Time Modified</source>
        <translation>Muutosaika</translation>
    </message>
    <message>
        <source>SIG</source>
        <translation>SIG</translation>
    </message>
    <message>
        <source>EXE</source>
        <translation>EXE</translation>
    </message>
    <message>
        <source>Core File</source>
        <translation>Core-tiedosto</translation>
    </message>
    <message>
        <source>User Name </source>
        <translation>Käyttäjänimi</translation>
    </message>
    <message>
        <source>Offset</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Päivä ja aika</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Järjestelmä</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Kernel</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Boot</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>dpkg</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Kwin loki</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Sovellukset</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Kirjautumiset</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>dnf loki</translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation>Muu loki</translation>
    </message>
    <message>
        <source>Custom Log</source>
        <translation>Mukautettu loki</translation>
    </message>
    <message>
        <source>Audit Log</source>
        <translation>Tarkastuslogi:</translation>
    </message>
    <message>
        <source>Coredump Log</source>
        <translation>Coredump loki</translation>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation>Kaatumistietoja ei voi saada, asenna systemd-coredump.</translation>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation>Sinulla ei ole lupaa tarkastella sitä</translation>
    </message>
    <message>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation>Järjestelmän suojaustaso: korkea
Vain järjestelmänvalvojat voivat katsoa valvontalokia</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Export logs to the specified path</source>
        <translation>Vie lokit määriteltyyn polkuun</translation>
    </message>
    <message>
        <source>PATH</source>
        <translation>POLKU</translation>
    </message>
    <message>
        <source>Export logs of specified types</source>
        <translation>Vie tietyntyyppiset lokit</translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation>TYYPPI</translation>
    </message>
    <message>
        <source>Export logs of specified self-developed applications</source>
        <translation>Vie itse kehitettyjen sovellusten lokit</translation>
    </message>
    <message>
        <source>SELF APPNAME</source>
        <translation>OMA SOVELLUS</translation>
    </message>
    <message>
        <source>Export logs within a specified time period</source>
        <translation>Vie lokit tietyn ajan kuluessa</translation>
    </message>
    <message>
        <source>PERIOD</source>
        <translation>AJANJAKSO</translation>
    </message>
    <message>
        <source>Export logs within a specified debug level</source>
        <translation>Vie lokit virheenkorjaustasolla</translation>
    </message>
    <message>
        <source>LEVEL</source>
        <translation>TASO</translation>
    </message>
    <message>
        <source>BOOT STATUS</source>
        <translation>KÄYNNISTYSTILA</translation>
    </message>
    <message>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation>Vie boot(no-klu) -lokit määritetyssä tilassa</translation>
    </message>
    <message>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation>Vie boot-shutdown-event tai valvontalokit tietyn tapahtumatyypin sisällä</translation>
    </message>
    <message>
        <source>EVENT TYPE</source>
        <translation>TAPAHTUMATYYPPI</translation>
    </message>
    <message>
        <source>Export logs based on keywords search results</source>
        <translation>Vie lokit hakutulosten perusteella</translation>
    </message>
    <message>
        <source>KEY WORD</source>
        <translation>HAKUSANA</translation>
    </message>
    <message>
        <source>Report coredump informations.</source>
        <translation>Ilmoita perustiedot.</translation>
    </message>
    <message>
        <source>Export logs based on app submodel</source>
        <translation>Vie lokit sovelluksen alamoduulin perusteella</translation>
    </message>
    <message>
        <source>SUBMODULE</source>
        <translation>ALAMODUULI</translation>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation>Virkistysväli</translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation>10 s</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation>1 min</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation>5 min</translation>
    </message>
    <message>
        <source>No refresh</source>
        <translation>Ei virkistystä</translation>
    </message>
    <message>
        <source>Export All</source>
        <translation>Vie kaikki</translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation>Virkistä nyt</translation>
    </message>
</context>
</TS>
